<style>
.md-content__inner > h1:nth-child(1) {
  display: none;
}
</style>


::: pydepot.abc.StoreSubscriber
    options:
        show_root_heading: true
        merge_init_into_class: false
        show_bases: true
        show_root_full_path: false
        show_source: false
::: pydepot.abc.subscriber.TState
    options:
        show_root_heading: true
        show_root_full_path: false
